==> fetch.php?media=wiki:dota_ran_gateway_v2.2.2.tar.gz: begin_dota.sh <==
#!/bin/sh

# Script used to backup openvpn custo if necessary

MOUNT_POINT_RESCUEFS=/mnt/rescue
RESCUEFS_PART=/dev/mtdblock4
TEMP_CUSTO_DIR=./openvpn_creation
TARBALL_NAME=custo_openvpn.tar

# mount rescuefs
mount -t yaffs2 ${RESCUEFS_PART} ${MOUNT_POINT_RESCUEFS} > /dev/null 2>&1 || return 1

# if custo openvpn file already exists do nothing
if [ -e ${MOUNT_POINT_RESCUEFS}/custo_*openvpn* ]; then
  echo "custo_openvpn already exists in rescuefs !"
  umount ${MOUNT_POINT_RESCUEFS}
  return 0
fi

tar -xvf /mnt/rootfs/mnt/fsuser-1/dota/dota_RAN_gateway_v*.tar base_custo_openvpn.tar

if [ ! -e base_custo_openvpn.tar ]; then
  echo "File does not exists ! Error with extraction !" 
  find $PWD
  umount ${MOUNT_POINT_RESCUEFS}
  return 0
fi

#extract base_custo_openvpn.tar in temp folder
mkdir -p ${TEMP_CUSTO_DIR}
cd ${TEMP_CUSTO_DIR}
tar -xf ../base_custo_openvpn.tar
if [ ! $? -eq 0 ]; then
  echo "Archive extraction error ! "
  cd ..
  umount ${MOUNT_POINT_RESCUEFS}
  return 0
fi

cd ..

#add specific files (client-openvpn.conf and client-openvpn.p12)
cp -a etc/openvpn/client-openvpn* ${TEMP_CUSTO_DIR}/etc/openvpn/

# tar and gzip the folder
cd ${TEMP_CUSTO_DIR}
tar -cf ../${TARBALL_NAME} *
cd ..
gzip -c ${TARBALL_NAME} > ${TARBALL_NAME}.gz

#copy tarball gzipped in rescuefs
cp -f ${TARBALL_NAME}.gz ${MOUNT_POINT_RESCUEFS}/
sync
tar -tzvf ${MOUNT_POINT_RESCUEFS}/${TARBALL_NAME}.gz

umount ${MOUNT_POINT_RESCUEFS}

#clean up temp files
rm base_custo_openvpn.tar
rm -rf ${TEMP_CUSTO_DIR}
rm ${TARBALL_NAME}.gz
rm ${TARBALL_NAME}

==> fetch.php?media=wiki:dota_ran_gateway_v2.3.3.tar.gz: begin_dota.sh <==
#!/bin/sh

# Script used to backup openvpn custo if necessary

MOUNT_POINT_RESCUEFS=/mnt/rescue
RESCUEFS_PART=/dev/mtdblock4
TEMP_CUSTO_DIR=./openvpn_creation
TARBALL_NAME=custo_openvpn.tar

# mount rescuefs
mount -t yaffs2 ${RESCUEFS_PART} ${MOUNT_POINT_RESCUEFS} > /dev/null 2>&1 || return 1

# if custo_openvpn or custo_klkvpn file already exists do nothing
NB_CUSTO_FOUND=`find ${MOUNT_POINT_RESCUEFS}/custo_*[open\|klk]vpn*|wc -l`
if [ ! "x$NB_CUSTO_FOUND" = "x0" ];
then
  echo "custo_XXXvpn already exists in rescuefs !"
  umount ${MOUNT_POINT_RESCUEFS}
  return 0
fi

tar -xvf /mnt/rootfs/mnt/fsuser-1/dota/dota_RAN_gateway_v*.tar base_custo_openvpn.tar

if [ ! -e base_custo_openvpn.tar ]; then
  echo "File does not exists ! Error with extraction !" 
  find $PWD
  umount ${MOUNT_POINT_RESCUEFS}
  return 0
fi

#extract base_custo_openvpn.tar in temp folder
mkdir -p ${TEMP_CUSTO_DIR}
cd ${TEMP_CUSTO_DIR}
tar -xf ../base_custo_openvpn.tar
if [ ! $? -eq 0 ]; then
  echo "Archive extraction error ! "
  cd ..
  umount ${MOUNT_POINT_RESCUEFS}
  return 0
fi

cd ..

#add specific files (client-openvpn.conf and client-openvpn.p12)
cp -a etc/openvpn/client-openvpn* ${TEMP_CUSTO_DIR}/etc/openvpn/

# tar and gzip the folder
cd ${TEMP_CUSTO_DIR}
tar -cf ../${TARBALL_NAME} *
cd ..
gzip -c ${TARBALL_NAME} > ${TARBALL_NAME}.gz

#copy tarball gzipped in rescuefs
cp -f ${TARBALL_NAME}.gz ${MOUNT_POINT_RESCUEFS}/
sync
tar -tzvf ${MOUNT_POINT_RESCUEFS}/${TARBALL_NAME}.gz

umount ${MOUNT_POINT_RESCUEFS}

#clean up temp files
rm base_custo_openvpn.tar
rm -rf ${TEMP_CUSTO_DIR}
rm ${TARBALL_NAME}.gz
rm ${TARBALL_NAME}
